/*
 * Copyright © 2014 Keith Packard <keithp@keithp.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 */

package org.altusmetrum.altoslib_14;

import java.io.*;
import java.lang.Math;
import java.util.*;
import java.util.concurrent.*;

public abstract class AltosMapMark {

	public AltosLatLon	lat_lon;
	public int		state;
	public String		label;

	static public int stroke_width = 6;

	public abstract void paint(AltosMapTransform t);

	public AltosMapMark (double lat, double lon, int state, String label) {
		lat_lon = new AltosLatLon(lat, lon);
		this.state = state;
		this.label = label;
	}

	public AltosMapMark (double lat, double lon, int state) {
		this(lat, lon, state, null);
	}

	public AltosMapMark () {
		this(0, 0, 0);
	}
}
